==> pw-iso20022-SRU2022-9.3.2-sources.jar: com/prowidesoftware/swift/model/mx/dic/AgreedAmount1.java <==

package com.prowidesoftware.swift.model.mx.dic;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * Provides details about the agreed amount for the variation margin and optionaly the segregated independent amount.
 * 
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "AgreedAmount1", propOrder = {
    "vartnMrgnAmt",
    "sgrtdIndpdntAmt"
})
public class AgreedAmount1 {

    @XmlElement(name = "VartnMrgnAmt", required = true)
    protected Amount1 vartnMrgnAmt;
    @XmlElement(name = "SgrtdIndpdntAmt")
    protected Amount1 sgrtdIndpdntAmt;

    /**
     * Gets the value of the vartnMrgnAmt property.
     * 
     * @return
     *     possible object is
     *     {@link Amount1 }
     *     
     */
    public Amount1 getVartnMrgnAmt() {
        return vartnMrgnAmt;
    }

    /**
     * Sets the value of the vartnMrgnAmt property.
     * 
     * @param value
     *     allowed object is
     *     {@link Amount1 }
     *     
     */
    public AgreedAmount1 setVartnMrgnAmt(Amount1 value) {
        this.vartnMrgnAmt = value;
        return this;
    }

    /**
     * Gets the value of the sgrtdIndpdntAmt property.
     * 
     * @return
     *     possible object is
     *     {@link Amount1 }
     *     
     */
    public Amount1 getSgrtdIndpdntAmt() {
        return sgrtdIndpdntAmt;
    }

    /**
     * Sets the value of the sgrtdIndpdntAmt property.
     * 
     * @param value
     *     allowed object is
     *     {@link Amount1 }
     *     
     */
    public AgreedAmount1 setSgrtdIndpdntAmt(Amount1 value) {
        this.sgrtdIndpdntAmt = value;
        return this;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

}

==> pw-iso20022-SRU2024-10.2.3-sources.jar: com/prowidesoftware/swift/model/mx/dic/AgreedAmount1.java <==

package com.prowidesoftware.swift.model.mx.dic;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * Provides details about the agreed amount for the variation margin and optionaly the segregated independent amount.
 * 
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "AgreedAmount1", propOrder = {
    "vartnMrgnAmt",
    "sgrtdIndpdntAmt"
})
public class AgreedAmount1 {

    @XmlElement(name = "VartnMrgnAmt", required = true)
    protected Amount1 vartnMrgnAmt;
    @XmlElement(name = "SgrtdIndpdntAmt")
    protected Amount1 sgrtdIndpdntAmt;

    /**
     * Gets the value of the vartnMrgnAmt property.
     * 
     * @return
     *     possible object is
     *     {@link Amount1 }
     *     
     */
    public Amount1 getVartnMrgnAmt() {
        return vartnMrgnAmt;
    }

    /**
     * Sets the value of the vartnMrgnAmt property.
     * 
     * @param value
     *     allowed object is
     *     {@link Amount1 }
     *     
     */
    public AgreedAmount1 setVartnMrgnAmt(Amount1 value) {
        this.vartnMrgnAmt = value;
        return this;
    }

    /**
     * Gets the value of the sgrtdIndpdntAmt property.
     * 
     * @return
     *     possible object is
     *     {@link Amount1 }
     *     
     */
    public Amount1 getSgrtdIndpdntAmt() {
        return sgrtdIndpdntAmt;
    }

    /**
     * Sets the value of the sgrtdIndpdntAmt property.
     * 
     * @param value
     *     allowed object is
     *     {@link Amount1 }
     *     
     */
    public AgreedAmount1 setSgrtdIndpdntAmt(Amount1 value) {
        this.sgrtdIndpdntAmt = value;
        return this;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

}
